@@ -4,7 +4,7 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     04/03/2006
-// RCS-ID:      $Id: me_constants.cpp,v 1.1 2006/03/10 19:25:33 mbarbon Exp $
+// RCS-ID:      $Id: me_constants.cpp,v 1.2 2006/07/02 14:03:29 mbarbon Exp $
 // Copyright:   (c) 2006 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
@@ -43,5 +43,5 @@ double media_constant( const char* name, int arg )
     WX_PL_CONSTANT_CLEANUP();
 }
 
-wxPlConstants xrc_module( &xrc_constant );
+wxPlConstants media_module( &media_constant );
 
